@@ -15,12 +15,13 @@ Puppet::Type.type(:nova_aggregate).provide(
   def self.instances
     request('aggregate', 'list').collect do |el|
       attrs = request('aggregate', 'show', el[:name])
+      properties = parsestring(attrs[:properties]) rescue nil
       new(
           :ensure => :present,
           :name => attrs[:name],
           :id => attrs[:id],
           :availability_zone => attrs[:availability_zone],
-          :metadata => str2hash(attrs[:properties]),
+          :metadata => properties,
           :hosts => string2list(attrs[:hosts]).sort,
           :filter_hosts => attrs[:filter_hosts]
       )
@@ -55,6 +56,7 @@ Puppet::Type.type(:nova_aggregate).provide(
       self.class.request('aggregate', 'remove host', properties)
     end
     self.class.request('aggregate', 'delete', @property_hash[:name])
+    @property_hash.clear
   end
 
   def create
@@ -78,6 +80,7 @@ Puppet::Type.type(:nova_aggregate).provide(
         self.class.request('aggregate', 'add host', properties)
       end
     end
+    @property_hash[:ensure] = :present
   end
 
   def availability_zone=(value)
@@ -117,4 +120,22 @@ Puppet::Type.type(:nova_aggregate).provide(
     end
   end
 
+  def self.string2hash(input)
+    return Hash[input.scan(/(\S+)='([^']*)'/)]
+  end
+
+  def self.pythondict2hash(input)
+    return JSON.parse(input.gsub(/u'([^']*)'/, '"\1"').gsub(/'/, '"'))
+  end
+
+  def self.parsestring(input)
+    if input[0] == '{'
+      # 4.0.0+ output, python dict
+      return self.pythondict2hash(input)
+    else
+      # Pre-4.0.0 output, key=value
+      return self.string2hash(input)
+    end
+  end
+
 end
