@@ -23,14 +23,23 @@ describe 'basic nova' do
         require           => Class['nova::api'],
       }
 
-      nova_flavor { 'test_flavor':
-        ensure  => present,
-        name    => 'test_flavor',
-        id      => '9999',
-        ram     => '512',
-        disk    => '1',
-        vcpus   => '1',
-        require => [ Class['nova::api'], Class['nova::keystone::auth'] ],
+      nova_flavor { 'public_flavor':
+        ensure => present,
+        name   => 'public_flavor',
+        id     => '42',
+        ram    => '512',
+        disk   => '1',
+        vcpus  => '1',
+      }
+      nova_flavor { 'private_flavor':
+        ensure       => present,
+        name         => 'private_flavor',
+        id           => '43',
+        ram          => '512',
+        disk         => '1',
+        vcpus        => '1',
+        is_public    => 'False',
+        project_name => 'services'
       }
       EOS
 
@@ -59,20 +68,21 @@ describe 'basic nova' do
     end
 
     describe cron do
-      it { is_expected.to have_entry('1 0 * * * nova-manage db archive_deleted_rows  --max_rows 100    >>/var/log/nova/nova-rowsflush.log 2>&1').with_user('nova') }
+      it { is_expected.to have_entry('1 0 * * * nova-manage db archive_deleted_rows --max_rows 100 >>/var/log/nova/nova-rowsflush.log 2>&1').with_user('nova') }
     end
 
     describe 'nova aggregate' do
       it 'should create new aggregate' do
-        shell('openstack --os-identity-api-version 3 --os-username nova --os-password a_big_secret --os-tenant-name services --os-user-domain-name Default --os-project-domain-name Default --os-auth-url http://127.0.0.1:5000/v3 aggregate list') do |r|
+        command('openstack --os-identity-api-version 3 --os-username nova --os-password a_big_secret --os-tenant-name services --os-user-domain-name Default --os-project-domain-name Default --os-auth-url http://127.0.0.1:5000/v3 aggregate list') do |r|
           expect(r.stdout).to match(/test_aggregate/)
         end
       end
     end
     describe 'nova flavor' do
       it 'should create new flavor' do
-        shell('openstack --os-identity-api-version 3 --os-username nova --os-password a_big_secret --os-tenant-name services --os-user-domain-name Default --os-project-domain-name Default --os-auth-url http://127.0.0.1:5000/v3 flavor list') do |r|
-          expect(r.stdout).to match(/test_flavor/)
+        command('openstack --os-identity-api-version 3 --os-username nova --os-password a_big_secret --os-tenant-name services --os-user-domain-name Default --os-project-domain-name Default --os-auth-url http://127.0.0.1:5000/v3 flavor list') do |r|
+          expect(r.stdout).to match(/public_flavor/)
+          expect(r.stdout).to match(/private_flavor/)
         end
       end
     end
