@@ -58,6 +58,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/sysinfo_serial').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/device_detach_timeout').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
@@ -92,6 +93,7 @@ describe 'nova::compute::libvirt' do
           :disk_cachemodes                            => ['file=directsync','block=none'],
           :hw_disk_discard                            => 'unmap',
           :hw_machine_type                            => 'x86_64=machinetype1,armv7l=machinetype2',
+          :sysinfo_serial                             => 'auto',
           :enabled_perf_events                        => ['cmt', 'mbml', 'mbmt'],
           :device_detach_attempts                     => 8,
           :device_detach_timeout                      => 20,
@@ -117,6 +119,7 @@ describe 'nova::compute::libvirt' do
           :ovs_timeout                                => 10,
           :max_queues                                 => 4,
           :num_memory_encrypted_guests                => 255,
+          :modular_libvirt                            => true,
         }
       end
 
@@ -135,6 +138,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_value('file=directsync,block=none')}
       it { is_expected.to contain_nova_config('libvirt/hw_disk_discard').with_value('unmap')}
       it { is_expected.to contain_nova_config('libvirt/hw_machine_type').with_value('x86_64=machinetype1,armv7l=machinetype2')}
+      it { is_expected.to contain_nova_config('libvirt/sysinfo_serial').with_value('auto')}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('cmt,mbml,mbmt')}
       it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value(8)}
       it { is_expected.to contain_nova_config('libvirt/device_detach_timeout').with_value(20)}
@@ -152,10 +156,6 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('libvirt')}
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value(4)}
       it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value(255)}
-      it { is_expected.to contain_libvirtd_config('log_outputs').with_value('1:file:/var/log/libvirt/libvirtd.log').with_quote(true) }
-      it { is_expected.to contain_libvirtd_config('log_filters').with_value('1:qemu').with_quote(true) }
-      it { is_expected.to contain_libvirtd_config('tls_priority').with_value('NORMAL:-VERS-SSL3.0').with_quote(true) }
-      it { is_expected.to contain_libvirtd_config('ovs_timeout').with_value(10)}
       it {
         is_expected.to contain_service('libvirt').with(
           :name     => 'custom_service',
